% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convert.R
\name{model_to_edgelist_file}
\alias{model_to_edgelist_file}
\title{Convert a model file and write the edge list to disk}
\usage{
model_to_edgelist_file(path, out_path = NULL, format = NULL)
}
\arguments{
\item{path}{Path to the model file.}

\item{out_path}{Output file (.csv or .xlsx). If \code{NULL}, the model's
name with an \code{_edgelist.csv} suffix is used.}

\item{format}{See \code{\link{model_to_edgelist}}.}
}
\value{
(invisibly) the edge list data.frame.
}
\description{
Convert a model file and write the edge list to disk
}
\examples{
mdl <- system.file("extdata", "example_model.mdl", package = "CLDedgelister")
out <- tempfile(fileext = ".csv")
model_to_edgelist_file(mdl, out)
}
