% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/convert.R
\name{cld_formats}
\alias{cld_formats}
\title{Supported model formats}
\usage{
cld_formats()
}
\value{
A character vector of the format labels the package understands.
}
\description{
Supported model formats
}
\examples{
cld_formats()
}
