% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CLDedgelister-package.R
\docType{package}
\name{CLDedgelister-package}
\alias{CLDedgelister}
\alias{CLDedgelister-package}
\title{CLDedgelister: Import System-Dynamics Models and Convert Them to Edge Lists}
\description{
Imports causal / system-dynamics models from Vensim, Stella / iThink,
Powersim Studio, AnyLogic and GoldSim, and converts them into a two-column
INPUT -> OUTPUT edge list.
}
\author{
\strong{Maintainer}: Taddias Prince Mpofu \email{princetaddy@gmail.com}

Authors:
\itemize{
  \item Joel Runyu
}
}
\keyword{internal}
